__author__ = 'maruf'

import json

from bson import ObjectId

class MongoObjectJSONEncoder(json.JSONEncoder):
    def default(self, o):
        if isinstance(o, ObjectId):
            return str(o)
        return json.JSONEncoder.default(self, o)